@@ -1225,3 +1225,31 @@ def iter_reshape(seq, how):
                 i += n
         rv[k] = container(_rv)
     return type(seq)(rv)
+
+
+def iter_rotate_left(iterable, n, onlyfinal=False):
+    try:
+        iterable_ = iterable.copy()
+    except Exception:
+        iterable_ = iterable
+
+    for _ in range(n):
+        iterable_ = iterable_[1:] + iterable_[:1]
+        if not onlyfinal:
+            yield iterable_
+    if onlyfinal:
+        yield iterable_
+
+
+def iter_rotate_right(iterable, n, onlyfinal=False):
+    try:
+        iterable_ = iterable.copy()
+    except Exception:
+        iterable_ = iterable
+
+    for _ in range(n):
+        iterable_ = iterable_[-1:] + iterable_[:-1]
+        if not onlyfinal:
+            yield iterable_
+    if onlyfinal:
+        yield iterable_
